# Class: role

A set of permissions associated with a subject

## Fields for class: role

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`is_internal`       |`bool`              |_RO/runtime_   |Indicates whether the role is only to be assigned internally by xapi, or can be used by clients|
|`name_description`  |`string`            |_RO/constructor_|what this role is for                   |
|`name_label`        |`string`            |_RO/constructor_|a short user&#45;friendly name for the role|
|`subroles`          |`role ref set`      |_RO/constructor_|a list of pointers to other roles or permissions|
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |

## RPCs associated with class: role

### RPC name: get&#95;all

_Overview:_

Return a list of all the roles known to the system.

_Signature:_

```
role ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of role references to role records for all roles known to the system.

_Signature:_

```
(role ref -> role record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(role ref -> role record) map`

records of all objects

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the role instances with the given label.

_Signature:_

```
role ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;permission

_Overview:_

This call returns a list of roles given a permission

_Signature:_

```
role ref set get_by_permission (session ref session_ref, role ref permission)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`role ref`                    |`permission`                  |a reference to a permission             |

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

a list of references to roles

### RPC name: get&#95;by&#95;permission&#95;name&#95;label

_Overview:_

This call returns a list of roles given a permission name

_Signature:_

```
role ref set get_by_permission_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |The short friendly name of the role     |

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

a list of references to roles

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the role instance with the specified UUID.

_Signature:_

```
role ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `role ref`

reference to the object

### RPC name: get&#95;is&#95;internal

_Overview:_

Get the is&#95;internal field of the given role.

_Signature:_

```
bool get_is_internal (session ref session_ref, role ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`role ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given role.

_Signature:_

```
string get_name_description (session ref session_ref, role ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`role ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given role.

_Signature:_

```
string get_name_label (session ref session_ref, role ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`role ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;permissions

_Overview:_

This call returns a list of permissions given a role

_Signature:_

```
role ref set get_permissions (session ref session_ref, role ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`role ref`                    |`self`                        |a reference to a role                   |

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

a list of permissions

### RPC name: get&#95;permissions&#95;name&#95;label

_Overview:_

This call returns a list of permission names given a role

_Signature:_

```
string set get_permissions_name_label (session ref session_ref, role ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`role ref`                    |`self`                        |a reference to a role                   |

_Minimum Role:_ read-only

_Return Type:_ `string set`

a list of permission names

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given role.

_Signature:_

```
role record get_record (session ref session_ref, role ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`role ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `role record`

all fields from the object

### RPC name: get&#95;subroles

_Overview:_

Get the subroles field of the given role.

_Signature:_

```
role ref set get_subroles (session ref session_ref, role ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`role ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given role.

_Signature:_

```
string get_uuid (session ref session_ref, role ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`role ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field
